@@ -120,7 +120,7 @@ class SessionObject:
         
       
         if req == '/index.html':
-          r = requests.get(core+'/', headers=headers, params=params)
+          r = requests.get(core+, headers=headers, params=self.baseParams)
         else:
           r = requests.get(host+req, headers=headers, params=params)
         c = r.content
